@@ -579,7 +579,7 @@ display_about_dialog (BonoboUIComponent *uic,
 		
 	fish->about_dialog = gtk_about_dialog_new ();
 	g_object_set (fish->about_dialog,
-		      "name", _("Fish"),
+		      "program-name", _("Fish"),
 		      "version", "3.4.7.4ac19",
 		      "copyright", "Copyright \xc2\xa9 1998-2002 Free Software Foundation, Inc.",
 		      "comments", descr,
@@ -1707,7 +1707,7 @@ set_tooltip (FishApplet *fish)
 	char       *desc;
 
 	desc = g_markup_printf_escaped (desc_format, fish->name);
-	g_object_set (fish, "tooltip-markup", desc, NULL);
+	gtk_widget_set_tooltip_markup (GTK_WIDGET (fish), desc);
 	g_free (desc);
 }
 
